@@ -30,7 +30,7 @@ const { LambdaToDynamoDBProps,  LambdaToDynamoDB } from '@aws-solutions-construc
 const props: LambdaToDynamoDBProps = {
     lambdaFunctionProps: {
         code: lambda.Code.fromAsset(`${__dirname}/lambda`),
-        runtime: lambda.Runtime.NODEJS_12_X,
+        runtime: lambda.Runtime.NODEJS_14_X,
         handler: 'index.handler'
     },
 };
@@ -171,7 +171,7 @@ class LambdaToDynamoDB(
             vpc_props=vpc_props,
         )
 
-        jsii.create(LambdaToDynamoDB, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="dynamoTable")
